@@ -7,7 +7,7 @@ use WWW::Mechanize;
 use Encode;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 my %lang_pairs = (
@@ -202,7 +202,7 @@ WWW::Translate::interNOSTRUM - Catalan < > Spanish machine translation
 
 =head1 VERSION
 
-Version 0.09 February 14, 2007
+Version 0.10 April 6, 2007
 
 
 =head1 SYNOPSIS
@@ -240,8 +240,8 @@ Version 0.09 February 14, 2007
 
 interNOSTRUM is a Catalan < > Spanish machine translation engine developed by
 the Department of Software and Computing Systems of the University of Alicante
-in Spain. This module provides an OO interface to the interNOSTRUM engine
-web server.
+in Spain. This module provides an OO interface to the interNOSTRUM online
+translation engine.
 
 interNOSTRUM provides approximate translations of Catalan into Spanish and
 Spanish into Catalan. It generates both the central variant of Oriental
@@ -333,7 +333,7 @@ interNOSTRUM engine object:
 
 Returns the translation of $string generated by interNOSTRUM.
 $string must be a string of ANSI text, and can contain up to 16,384 characters.
-If the source text isn't encoded as Latin-1, you must convert it to Latin-1
+If the source text isn't encoded as Latin-1, you must convert it to that encoding
 before sending it to the machine translation engine. For this task you can use
 the Encode module or the PerlIO layer, if you are reading the text from a file.
 
@@ -377,6 +377,9 @@ Source language is Spanish.
 
 WWW::Mechanize 1.20 or higher.
 
+=head1 SEE ALSO
+
+WWW::Translate::Apertium
 
 =head1 REFERENCES
 
